Summary:    Scientific Tools for Python
Name:       python3-scipy
Version:    0.18.1
Release:    2%{?dist}

# BSD -- whole package except:
# Boost -- scipy/special/cephes/scipy_iv.c
# Public Domain -- scipy/odr/__odrpack.c
License:    BSD and Boost and Public Domain
Url:        http://www.scipy.org/scipylib/index.html
Source0:    https://pypi.io/packages/source/s/scipy/scipy-%{version}.tar.gz
# Fix up premissions
# https://bugzilla.redhat.com/show_bug.cgi?id=1358041
# https://github.com/scipy/scipy/pull/6694
Patch0:     scipy-perms.patch

BuildRequires:  atlas-devel
BuildRequires:  fftw-devel
BuildRequires:  gcc-gfortran
BuildRequires:  qhull-devel
BuildRequires:  suitesparse-devel
BuildRequires:  swig

%description
Scipy is open-source software for mathematics, science, and
engineering. The core library is NumPy which provides convenient and
fast N-dimensional array manipulation. The SciPy library is built to
work with NumPy arrays, and provides many user-friendly and efficient
numerical routines such as routines for numerical integration and
optimization. Together, they run on all popular operating systems, are
quick to install, and are free of charge. NumPy and SciPy are easy to
use, but powerful enough to be depended upon by some of the world's
leading scientists and engineers.


%package -n python%{python3_pkgversion}-scipy
Summary:    Scientific Tools for Python
License:    BSD and LGPLv2+
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-nose
BuildRequires:  python%{python3_pkgversion}-numpy
BuildRequires:  python%{python3_pkgversion}-numpy-f2py
BuildRequires:  python%{python3_pkgversion}-setuptools
Requires:   python%{python3_pkgversion}-numpy
Requires:   python%{python3_pkgversion}-numpy-f2py
%{?python_provide:%python_provide python%{python3_pkgversion}-scipy}

%description -n python%{python3_pkgversion}-scipy
Scipy is open-source software for mathematics, science, and
engineering. The core library is NumPy which provides convenient and
fast N-dimensional array manipulation. The SciPy library is built to
work with NumPy arrays, and provides many user-friendly and efficient
numerical routines such as routines for numerical integration and
optimization. Together, they run on all popular operating systems, are
quick to install, and are free of charge. NumPy and SciPy are easy to
use, but powerful enough to be depended upon by some of the world's
leading scientists and engineers.


%prep
%setup -q -n scipy-%{version}
%patch0 -p1
cat > site.cfg << EOF

[amd]
library_dirs = %{_libdir}
include_dirs = /usr/include/suitesparse
amd_libs = amd

[umfpack]
library_dirs = %{_libdir}
include_dirs = /usr/include/suitesparse
umfpack_libs = umfpack
EOF


%build
env CFLAGS="$RPM_OPT_FLAGS" \
    FFLAGS="$RPM_OPT_FLAGS -fPIC" \
    ATLAS=%{_libdir}/atlas FFTW=%{_libdir} BLAS=%{_libdir} LAPACK=%{_libdir} \
    %__python3 setup.py config_fc \
    --fcompiler=gnu95 --noarch build


%install
env CFLAGS="$RPM_OPT_FLAGS" \
    FFLAGS="$RPM_OPT_FLAGS -fPIC" \
    ATLAS=%{_libdir}/atlas FFTW=%{_libdir} BLAS=%{_libdir} LAPACK=%{_libdir} \
    %__python3 setup.py install --root=$RPM_BUILD_ROOT
# Fixup .so permissions
find $RPM_BUILD_ROOT%{python3_sitearch} -name \*.so | xargs chmod 755 
# Fixup .py shebangs
find $RPM_BUILD_ROOT%{python3_sitearch} -name \*.py -a \! -executable | xargs sed -i -e '1{\@^#! */usr/bin/@d}'


%check
mkdir -p test3
cd test3
PYTHONPATH=$RPM_BUILD_ROOT%{python3_sitearch} \
    %__python3 -c "import scipy; scipy.test('full', verbose=2)"


%files -n python%{python3_pkgversion}-scipy
%license LICENSE.txt
%{python3_sitearch}/scipy
%{python3_sitearch}/*.egg-info


%changelog
* Thu Mar 07 2019 Troy Dawson <tdawson@redhat.com>
- Rebuilt to change main python from 3.4 to 3.6

* Mon Oct 17 2016 Orion Poplawski <orion@cora.nwra.com> - 0.18.1-1
- Update to 0.18.1
- Fix up file permissions/shebangs

* Tue Jul 19 2016 Orion Poplawski <orion@cora.nwra.com> - 0.17.1-1
- Update to 0.17.1

* Thu Mar 3 2016 Orion Poplawski <orion@cora.nwra.com> - 0.17.0-1
- Initial EPEL7 version
